@@ -420,7 +420,8 @@ class TestClientAdditionalMethods:
         assert filename == "test.csv"
         mock_open.assert_called_once()
         mock_writer_instance.writeheader.assert_called_once()
-        mock_writer_instance.writerows.assert_called_once()
+        # Check that writerow was called (at least once for the records)
+        assert mock_writer_instance.writerow.call_count >= 1
     
     @patch('builtins.open', new_callable=MagicMock)
     @patch('csv.DictWriter')
@@ -662,7 +663,7 @@ class TestClientCSVParameterSupport:
         mock_weather_data = Mock()
         mock_get_data.return_value = mock_weather_data
         
-        # Mock the CSV export
+        # Mock the CSV export - updated to match new return format
         mock_export.return_value = "auto_generated_daily.csv"
         
         # Call with csv=True
@@ -765,7 +766,7 @@ class TestClientCSVParameterSupport:
         mock_get_data.assert_called_once_with(
             [2], "2023-01-01", "2023-01-01", [], 'E', prioritize_scs=False
         )
-        mock_export.assert_called_once_with(mock_weather_data, None)
+        mock_export.assert_called_once_with(mock_weather_data, None, separate_daily_hourly=False)
     
     @patch('python_cimis.client.CimisClient.get_data')
     @patch('python_cimis.client.CimisClient.export_to_csv')
@@ -820,7 +821,7 @@ class TestClientCSVParameterSupport:
             [2, 6], "2023-01-01", "2023-01-01", 
             ["hly-air-tmp", "hly-rel-hum"], 'M', prioritize_scs=False
         )
-        mock_export.assert_called_once_with(mock_weather_data, "hourly_detailed.csv")
+        mock_export.assert_called_once_with(mock_weather_data, "hourly_detailed.csv", separate_daily_hourly=False)
 
 
 if __name__ == "__main__":
